Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-3]: src/sys/arch/xen/i386 Pull up revision 1.11 (requested by yam...



details:   https://anonhg.NetBSD.org/src/rev/c1151752938c
branches:  netbsd-3
changeset: 575675:c1151752938c
user:      tron <tron%NetBSD.org@localhost>
date:      Sun May 01 22:11:27 2005 +0000

description:
Pull up revision 1.11 (requested by yamt in ticket #238):
rename do_event to evtchan_do_event.
the former is too generic name and it actually hides a bug in xennetback.

diffstat:

 sys/arch/xen/i386/hypervisor_machdep.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (36 lines):

diff -r 08e1223822fb -r c1151752938c sys/arch/xen/i386/hypervisor_machdep.c
--- a/sys/arch/xen/i386/hypervisor_machdep.c    Sun May 01 22:09:47 2005 +0000
+++ b/sys/arch/xen/i386/hypervisor_machdep.c    Sun May 01 22:11:27 2005 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: hypervisor_machdep.c,v 1.4.2.6 2005/04/28 10:38:47 tron Exp $  */
+/*     $NetBSD: hypervisor_machdep.c,v 1.4.2.7 2005/05/01 22:11:27 tron Exp $  */
 
 /*
  *
@@ -59,7 +59,7 @@
 
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: hypervisor_machdep.c,v 1.4.2.6 2005/04/28 10:38:47 tron Exp $");
+__KERNEL_RCSID(0, "$NetBSD: hypervisor_machdep.c,v 1.4.2.7 2005/05/01 22:11:27 tron Exp $");
 
 #include <sys/cdefs.h>
 #include <sys/param.h>
@@ -191,7 +191,7 @@
                         * mask and clear the pending events.
                         * Doing it here for all event that will be processed
                         * avoids a race with stipending (which can be called
                         * though do_event->splx) that could cause an event to
                         * be both processed and marked pending.
                         */
                        x86_atomic_setbits_l(&s->evtchn_mask[l1i], l2);
@@ -207,7 +207,7 @@
                                        printf("do_hypervisor_callback event %d%d\n", port);
 #endif
                                if (evtsource[port])
-                                       do_event(port, regs);
+                                       evtchn_do_event(port, regs);
 #ifdef DOM0OPS
                                else
                                        xenevt_event(port);
@@ -191,7 +191,7 @@
                         * Doing it here for all event that will be processed
                         * avoids a race with stipending (which can be called
-                        * though do_event->splx) that could cause an event to
+                        * though evtchn_do_event->splx) that could cause an event to
                         * be both processed and marked pending.
                         */



Home | Main Index | Thread Index | Old Index